/**
 * This file has no copyright assigned and is placed in the Public Domain.
 * This file is part of the w64 mingw-runtime package.
 * No warranty is given; refer to the file DISCLAIMER.PD within this package.
 */
#define WPWIZ_ERROR_FIRST 0x40042000L
#define WPWIZ_ERROR_UNKNOWN 0xC0042001L
#define WPWIZ_ERROR_PROV_QI 0xC0042002L
#define WPWIZ_ERROR_INIT_FAILED 0xC0042003L
#define WPWIZ_ERROR_COCREATE_WEBPOST 0xC0042004L
#define WPWIZ_ERROR_NO_PROVIDERS 0xC0042005L
#define WPWIZ_ERROR_STATE_PTR 0xC0042006L
#define WPWIZ_ERROR_WEBPOST_PTR 0xC0042007L
#define WPWIZ_ERROR_FILE_NOT_FOUND 0xC0042008L
#define WPWIZ_ERROR_PROPSHEET_ERROR 0xC0042009L
#define WPWIZ_ERROR_OUTOFMEMORY 0xC004200AL
#define WPWIZ_ERROR_LAST 0x400420FFL
