/**
 * This file has no copyright assigned and is placed in the Public Domain.
 * This file is part of the w64 mingw-runtime package.
 * No warranty is given; refer to the file DISCLAIMER.PD within this package.
 */
#define WEBPOST_ERROR_FIRST 0x40042100L
#define WEBPOST_ERROR_UNKNOWN 0xC0042101L
#define WEBPOST_ERROR_PROVCLSID_UNKNOWN 0xC0042102L
#define WEBPOST_ERROR_SITE_CORRUPT 0xC0042103L
#define WEBPOST_ERROR_PROV_CORRUPT 0xC0042104L
#define WEBPOST_ERROR_PROV_DLL 0xC0042105L
#define WEBPOST_ERROR_PROV_EP 0xC0042106L
#define WEBPOST_ERROR_INIT_FAILED 0xC0042107L
#define WEBPOST_ERROR_LIST_SITES 0xC0042108L
#define WEBPOST_ERROR_SITE_EXISTS 0xC0042109L
#define WEBPOST_ERROR_CREATE_SITE 0xC004210AL
#define WEBPOST_ERROR_SITE_DOESNOTEXIST 0xC004210BL
#define WEBPOST_ERROR_DELETE_SITE 0xC004210CL
#define WEBPOST_ERROR_ENUM_PROVS 0xC004210DL
#define WEBPOST_ERROR_PROV_QI 0xC004210EL
#define WEBPOST_ERROR_POST_FILES 0xC004210FL
#define WEBPOST_ERROR_COCREATE_WIZARD 0xC0042110L
#define WEBPOST_ERROR_POSTINFO_REQUIRED 0xC0042111L
#define WEBPOST_ERROR_AUTOBIND_FAILED 0xC0042112L
#define WEBPOST_ERROR_BAD_PROV_PTR 0xC0042113L
#define WEBPOST_ERROR_PROV_NOT_IN_POSTINFO 0x80042114L
#define WEBPOST_ERROR_EXTENDED_ERROR 0xC0042116L
#define WEBPOST_ERROR_NO_EXT_ERR_INFO 0xC0042117L
#define WEBPOST_ERROR_INVALID_POSTINFO 0x40042118L
#define WEBPOST_ERROR_NO_POSTINFO 0x40042119L
#define WEBPOST_ERROR_HTTP_GET_FAILED 0x4004211AL
#define WEBPOST_ERROR_LAST 0x400421FFL
