/**
 * This file has no copyright assigned and is placed in the Public Domain.
 * This file is part of the w64 mingw-runtime package.
 * No warranty is given; refer to the file DISCLAIMER.PD within this package.
 */
#include "iads.h"
#include "adshlp.h"
#include "adserr.h"
#include "adsiid.h"
#include "adssts.h"
#include "adsnms.h"
#include "adsdb.h"
