/**
 * This file has no copyright assigned and is placed in the Public Domain.
 * This file is part of the w64 mingw-runtime package.
 * No warranty is given; refer to the file DISCLAIMER.PD within this package.
 */
#define CRSWPP_ERROR_FIRST 0x40042200L
#define CRSWPP_INVALID_POSTINFO_FILE 0xC0042201L
#define CRSWPP_NO_MATCHING_MAPURL 0xC0042202L
#define CRSWPP_SECURITY_PACKAGE 0xC0042203L
#define CRSWPP_SECURITY_PACKAGE_NOT_FOUND 0xC0042204L
#define CRSWPP_PROJECT_BINDING_INCOMPLETE 0xC0042205L
#define CRSWPP_SERVER_BINDING_INCOMPLETE 0xC0042206L
#define CRSWPP_SERVER_NOT_RESPONDING 0xC0042207L
#define CRSWPP_FAILED_AUTH 0xC0042208L
#define CRSWPP_POSTINFO_NEEDED 0x40042209L
#define CRSWPP_BIND_FAILED 0xC004220AL
