/**
 * This file has no copyright assigned and is placed in the Public Domain.
 * This file is part of the w64 mingw-runtime package.
 * No warranty is given; refer to the file DISCLAIMER.PD within this package.
 */
#define FTPWPP_ERROR_FIRST 0x40042300L
#define FTPWPP_ERROR_INETOPEN_FAILED 0xC0042301L
#define FTPWPP_ERROR_AUTHENTICATION_FAILED 0xC0042302L
#define FTPWPP_ERROR_LAST 0x400423FFL
