/**
 * This file has no copyright assigned and is placed in the Public Domain.
 * This file is part of the w64 mingw-runtime package.
 * No warranty is given; refer to the file DISCLAIMER.PD within this package.
 */
#ifndef _SHDISPID_H_
#define _SHDISPID_H_

#define DISPID_SELECTIONCHANGED 200
#define DISPID_FILELISTENUMDONE 201
#define DISPID_VERBINVOKED 202
#define DISPID_DEFAULTVERBINVOKED 203
#define DISPID_BEGINDRAG 204
#define DISPID_VIEWMODECHANGED 205
#define DISPID_NOITEMSTATE_CHANGED 206
#define DISPID_CONTENTSCHANGED 207
#define DISPID_FOCUSCHANGED 208
#define DISPID_ENTERPRESSED 200

#define DISPID_SEARCHCOMMAND_START 1
#define DISPID_SEARCHCOMMAND_COMPLETE 2
#define DISPID_SEARCHCOMMAND_ABORT 3
#define DISPID_SEARCHCOMMAND_UPDATE 4
#define DISPID_SEARCHCOMMAND_PROGRESSTEXT 5
#define DISPID_SEARCHCOMMAND_ERROR 6
#define DISPID_SEARCHCOMMAND_RESTORE 7

#define DISPID_IADCCTL_DIRTY 0x100
#define DISPID_IADCCTL_PUBCAT 0x101
#define DISPID_IADCCTL_SORT 0x102
#define DISPID_IADCCTL_FORCEX86 0x103
#define DISPID_IADCCTL_SHOWPOSTSETUP 0x104
#define DISPID_IADCCTL_ONDOMAIN 0x105
#define DISPID_IADCCTL_DEFAULTCAT 0x106

#endif
