/**
 * This file has no copyright assigned and is placed in the Public Domain.
 * This file is part of the w64 mingw-runtime package.
 * No warranty is given; refer to the file DISCLAIMER.PD within this package.
 */
#ifndef __TAPI3ERR_H__
#define __TAPI3ERR_H__

#define TAPI_E_NOTENOUGHMEMORY ((HRESULT)0x80040001L)
#define TAPI_E_NOITEMS ((HRESULT)0x80040002L)
#define TAPI_E_NOTSUPPORTED ((HRESULT)0x80040003L)
#define TAPI_E_INVALIDMEDIATYPE ((HRESULT)0x80040004L)
#define TAPI_E_OPERATIONFAILED ((HRESULT)0x80040005L)
#define TAPI_E_ALLOCATED ((HRESULT)0x80040006L)
#define TAPI_E_CALLUNAVAIL ((HRESULT)0x80040007L)
#define TAPI_E_COMPLETIONOVERRUN ((HRESULT)0x80040008L)
#define TAPI_E_CONFERENCEFULL ((HRESULT)0x80040009L)
#define TAPI_E_DIALMODIFIERNOTSUPPORTED ((HRESULT)0x8004000AL)
#define TAPI_E_INUSE ((HRESULT)0x8004000BL)
#define TAPI_E_INVALADDRESS ((HRESULT)0x8004000CL)
#define TAPI_E_INVALADDRESSSTATE ((HRESULT)0x8004000DL)
#define TAPI_E_INVALCALLPARAMS ((HRESULT)0x8004000EL)
#define TAPI_E_INVALCALLPRIVILEGE ((HRESULT)0x8004000FL)
#define TAPI_E_INVALCALLSTATE ((HRESULT)0x80040010L)
#define TAPI_E_INVALCARD ((HRESULT)0x80040011L)
#define TAPI_E_INVALCOMPLETIONID ((HRESULT)0x80040012L)
#define TAPI_E_INVALCOUNTRYCODE ((HRESULT)0x80040013L)
#define TAPI_E_INVALDEVICECLASS ((HRESULT)0x80040014L)
#define TAPI_E_INVALDIALPARAMS ((HRESULT)0x80040015L)
#define TAPI_E_INVALDIGITS ((HRESULT)0x80040016L)
#define TAPI_E_INVALGROUPID ((HRESULT)0x80040017L)
#define TAPI_E_INVALLOCATION ((HRESULT)0x80040018L)
#define TAPI_E_INVALMESSAGEID ((HRESULT)0x80040019L)
#define TAPI_E_INVALPARKID ((HRESULT)0x8004001AL)
#define TAPI_E_INVALRATE ((HRESULT)0x8004001BL)
#define TAPI_E_INVALTIMEOUT ((HRESULT)0x8004001CL)
#define TAPI_E_INVALTONE ((HRESULT)0x8004001DL)
#define TAPI_E_INVALLIST ((HRESULT)0x8004001EL)
#define TAPI_E_INVALMODE ((HRESULT)0x8004001FL)
#define TAPI_E_NOCONFERENCE ((HRESULT)0x80040020L)
#define TAPI_E_NODEVICE ((HRESULT)0x80040021L)
#define TAPI_E_NOREQUEST ((HRESULT)0x80040022L)
#define TAPI_E_NOTOWNER ((HRESULT)0x80040023L)
#define TAPI_E_NOTREGISTERED ((HRESULT)0x80040024L)
#define TAPI_E_REQUESTOVERRUN ((HRESULT)0x80040025L)
#define TAPI_E_TARGETNOTFOUND ((HRESULT)0x80040026L)
#define TAPI_E_TARGETSELF ((HRESULT)0x80040027L)
#define TAPI_E_USERUSERINFOTOOBIG ((HRESULT)0x80040028L)
#define TAPI_E_REINIT ((HRESULT)0x80040029L)
#define TAPI_E_ADDRESSBLOCKED ((HRESULT)0x8004002AL)
#define TAPI_E_BILLINGREJECTED ((HRESULT)0x8004002BL)
#define TAPI_E_INVALFEATURE ((HRESULT)0x8004002CL)
#define TAPI_E_INVALBUTTONLAMPID ((HRESULT)0x8004002DL)
#define TAPI_E_INVALBUTTONSTATE ((HRESULT)0x8004002EL)
#define TAPI_E_INVALDATAID ((HRESULT)0x8004002FL)
#define TAPI_E_INVALHOOKSWITCHDEV ((HRESULT)0x80040030L)
#define TAPI_E_DROPPED ((HRESULT)0x80040031L)
#define TAPI_E_NOREQUESTRECIPIENT ((HRESULT)0x80040032L)
#define TAPI_E_REQUESTQUEUEFULL ((HRESULT)0x80040033L)
#define TAPI_E_DESTBUSY ((HRESULT)0x80040034L)
#define TAPI_E_DESTNOANSWER ((HRESULT)0x80040035L)
#define TAPI_E_DESTUNAVAIL ((HRESULT)0x80040036L)
#define TAPI_E_REQUESTFAILED ((HRESULT)0x80040037L)
#define TAPI_E_REQUESTCANCELLED ((HRESULT)0x80040038L)
#define TAPI_E_INVALPRIVILEGE ((HRESULT)0x80040039L)
#define TAPI_E_INVALIDDIRECTION ((HRESULT)0x8004003AL)
#define TAPI_E_INVALIDTERMINAL ((HRESULT)0x8004003BL)
#define TAPI_E_INVALIDTERMINALCLASS ((HRESULT)0x8004003CL)
#define TAPI_E_NODRIVER ((HRESULT)0x8004003DL)
#define TAPI_E_MAXSTREAMS ((HRESULT)0x8004003EL)
#define TAPI_E_NOTERMINALSELECTED ((HRESULT)0x8004003FL)
#define TAPI_E_TERMINALINUSE ((HRESULT)0x80040040L)
#define TAPI_E_NOTSTOPPED ((HRESULT)0x80040041L)
#define TAPI_E_MAXTERMINALS ((HRESULT)0x80040042L)
#define TAPI_E_INVALIDSTREAM ((HRESULT)0x80040043L)
#define TAPI_E_TIMEOUT ((HRESULT)0x80040044L)
#define TAPI_E_CALLCENTER_GROUP_REMOVED ((HRESULT)0x80040045L)
#define TAPI_E_CALLCENTER_QUEUE_REMOVED ((HRESULT)0x80040046L)
#define TAPI_E_CALLCENTER_NO_AGENT_ID ((HRESULT)0x80040047L)
#define TAPI_E_CALLCENTER_INVALAGENTID ((HRESULT)0x80040048L)
#define TAPI_E_CALLCENTER_INVALAGENTGROUP ((HRESULT)0x80040049L)
#define TAPI_E_CALLCENTER_INVALPASSWORD ((HRESULT)0x8004004AL)
#define TAPI_E_CALLCENTER_INVALAGENTSTATE ((HRESULT)0x8004004BL)
#define TAPI_E_CALLCENTER_INVALAGENTACTIVITY ((HRESULT)0x8004004CL)
#define TAPI_E_REGISTRY_SETTING_CORRUPT ((HRESULT)0x8004004DL)
#define TAPI_E_TERMINAL_PEER ((HRESULT)0x8004004EL)
#define TAPI_E_PEER_NOT_SET ((HRESULT)0x8004004FL)
#define TAPI_E_NOEVENT ((HRESULT)0x80040050L)
#define TAPI_E_INVALADDRESSTYPE ((HRESULT)0x80040051L)
#define TAPI_E_RESOURCEUNAVAIL ((HRESULT)0x80040052L)
#define TAPI_E_PHONENOTOPEN ((HRESULT)0x80040053L)
#define TAPI_E_CALLNOTSELECTED ((HRESULT)0x80040054L)
#define TAPI_E_WRONGEVENT ((HRESULT)0x80040055L)
#define TAPI_E_NOFORMAT ((HRESULT)0x80040056L)
#define TAPI_E_INVALIDSTREAMSTATE ((HRESULT)0x80040057L)
#define TAPI_E_WRONG_STATE ((HRESULT)0x80040058L)
#define TAPI_E_NOT_INITIALIZED ((HRESULT)0x80040059L)
#define TAPI_E_SERVICE_NOT_RUNNING ((HRESULT)0x8004005AL)
#endif
