/**
 * This file has no copyright assigned and is placed in the Public Domain.
 * This file is part of the w64 mingw-runtime package.
 * No warranty is given; refer to the file DISCLAIMER.PD within this package.
 */
#ifndef _ADODEF_H_
#define _ADODEF_H_

#define ADO_MAJOR 2
#define ADOR_MAJOR 2
#define ADOX_MAJOR 2
#define ADOMD_MAJOR 2
#define JRO_MAJOR 2

#define ADO_MINOR 8
#define ADOR_MINOR 8
#define ADOX_MINOR 8
#define ADOMD_MINOR 8
#define JRO_MINOR 6

#define ADO_VERSION 2.8
#define ADOR_VERSION 2.8
#define ADOX_VERSION 2.8
#define ADOMD_VERSION 2.8
#define JRO_VERSION 2.6

#define ADO_HELPFILE "ado270.chm"
#define ADOX_HELPFILE "ado270.chm"
#define ADOMD_HELPFILE "ado270.chm"
#define JRO_HELPFILE "msjro.chm"

#define ADO_LIBRARYNAME "Microsoft ActiveX Data Objects 2.8 Library"
#define ADOR_LIBRARYNAME "Microsoft ActiveX Data Objects Recordset 2.8 Library"
#define ADOX_LIBRARYNAME "Microsoft ADO Ext. 2.8 for DDL and Security"
#define ADOMD_LIBRARYNAME "Microsoft ActiveX Data Objects (Multi-dimensional) 2.8 Library"
#define JRO_LIBRARYNAME "Microsoft Jet and Replication Objects 2.6 Library"

#define ADOMD_TYPELIB_UUID uuid(22813728-8BD3-11D0-B4EF-00A0C9138CA4)
#define JRO_TYPELIB_UUID uuid(AC3B8B4C-B6CA-11d1-9F31-00C04FC29D52)
#endif
