/* Generated automatically. */
static const char configuration_arguments[] = "../../../build/gcc/src/configure --target=i686-w64-mingw32 --host=x86_64-unknown-linux-gnu --prefix=/home/build/jenkins/jobs/Mingw-w64_32bit/workspace/build/root --with-sysroot=/home/build/jenkins/jobs/Mingw-w64_32bit/workspace/build/root --enable-languages=all,obj-c++ --enable-fully-dynamic-string --disable-multilib";
static const char thread_model[] = "win32";

static const struct {
  const char *name, *value;
} configure_default_options[] = { { "cpu", "generic" }, { "arch_32", "pentiumpro" }, { "arch_64", "x86-64" } };
