/**
 * This file has no copyright assigned and is placed in the Public Domain.
 * This file is part of the w64 mingw-runtime package.
 * No warranty is given; refer to the file DISCLAIMER.PD within this package.
 */
#define WPP_ERROR_FIRST 0x40042380L
#define WPP_POST_POSTING_URL_ERROR 0xC0042381L
#define WPP_POST_POSTING_SERVER_ERROR 0xC0042382L
#define WPP_POST_POSTING_NO_RESPONSE_ERROR 0xC0042383L
#define WPP_ERROR_LAST 0x400423FFL
